;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;
;; MODULE      : kbd-theophys-math.scm
;; DESCRIPTION : keybindings effective in math-mode only
;;
;; COPYRIGHT   : (C) 2003  Maarten Wegewijs
;;
;; This software falls under the GNU general public license and comes WITHOUT
;; ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for details.
;; If you don't have this file, write to the Free Software Foundation, Inc.,
;; 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(texmacs-module (keyboard kbd-theophys-math)
  (:use
    (utils edit auto-close)
    (math math-edit))
    (table table-edit))

(kbd-map
  (:mode in-math?)

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;;; Character formatting
;	 ("C-i" (make-with "math-font-series" "italic"))
;	 ("math:bold" "C-b" #t)
;	 ("C-b" (make-with "math-font-series" "bold"))
;;;; <space space> in math-mode = Bold font box
;	 ("space space" (make-with "math-font-series" "bold"))

;;; Switching to text mode
;;;; Insert text within math environment (e.g. name in subscript)
;;;; 
;;;; <$> in math-mode = Switch to Text mode COMMENT OUT IN kbd-math.scm
	 ("$" (make-with "mode" "text"))

;;;; <Shift-Return> in math-mode = Exit math/table/... by going to the right
	 ("S-return" (begin
		       (go-right)
		       )
	  )
;;;; <Control-Return> in math-mode = Exit the displayed math completely
	 ("C-return" (begin (kbd-end-line)
			    (go-right)
			    )
	  )
;;;; <Ctrl-Space> in math-mode = Toggle number (line in multiline) equation COMMENT OUT IN kbd-math.scm
	 ("C-space" (table-toggle-number-equation))


;;; Tables, Matrices, Boxes
;;;; Extend the these tables:
;;;;    Alt <down> = new row
;;;;    Alt <right>  = new column
;;;; The most frequently used table is centered on middle,  adjust via menu in those few cases you need something else.
;;;; 
;;;; <tab> in math-mode = Table without lines:
	 ("t a b" (begin (make 'tabular)
			 (table-insert-column #t)
			 (insert "=")
			 (table-insert-row #t)
			 (insert "=")
			 (table-insert-column #t)
			 (kbd-left)
			 )
	  )
;;("t a b" (make-compound-arg "tabular*"))
;;;; <box> in math-mode = box i.e. a 1x1 table with surrounding lines
;	 ("b o x" (make-compound-arg "block"))
	 ("b o x" (make 'block))
;;;; <w3j> in math-mode = Wigner 3j symbol i.e. a 2x3 matrix  with surrounding braces ( ) 
	 ("w 3 j" (begin  (make 'matrix)
			  (table-insert-row #f)
			  (table-insert-column #t)
			  (table-insert-column #t)
			  )
	  )
;;;; <mat> in math-mode = matrix i.e. a 2x2 matrix  with surrounding braces ( ) 
	 ("m a t" (begin  (make 'matrix)
			  (table-insert-row #f)
			  (table-insert-column #t)
			  )
	  )
;;;; <vec> in math-mode = matrix i.e. a 2x1 matrix  with surrounding braces ( ) 
	 ("v e c" (begin  (make 'matrix)
			  (table-insert-row #f)
			  )
	  )
;;;; <bin> in math-mode = binomial i.e. a 1x2 matrix  with surrounding braces ( ) 
	 ("b i n" (make 'binom));;; Brackets

;;;; Regular brackets: the stretchy brackets also look fine
;;;;  even when small arguments are used, so using them al the time is no problem
;;;; 
;;;; <(> in math-mode = open bracket ( (stretchy)  COMMENT OUT IN kbd-math.scm
	 ( "(" (make-bracket-open  "(" ")" #t))
;;;; <)> in math-mode = close bracket ) (stretchy)  COMMENT OUT IN kbd-math.scm
	 ( ")" (make-bracket-close ")" "(" #t))
;;;; <[> in math-mode = open bracket [ (stretchy)  COMMENT OUT IN kbd-math.scm
	 ( "[" (make-bracket-open  "[" "]" #t))
;;;; <]> in math-mode = close bracket ] (stretchy)  COMMENT OUT IN kbd-math.scm
	 ( "]" (make-bracket-close "]" "[" #t))
;;;; <{> in math-mode = open brace { (stretchy)  COMMENT OUT IN kbd-math.scm
	 ( "{" (make-bracket-open  "{" "}" #t))
;;;; <}> in math-mode = close brace } (stretchy)  COMMENT OUT IN kbd-math.scm
	 ( "}" (make-bracket-close "}" "{" #t))
;;;; <abs> in math-mode = absolute value (stretchy)
	 ( "a b s" (make-bracket-open "|" "|" #t))

;;; Dirac Bra- Kets
;;;; Stretchy kets & bra's look ugly in general
;;;; 
;;;; <b r k t> in math-mode = average  <  > (stretchy)
	 ( "b r k t" (make-bracket-open "langle" "rangle" #t))
;;;; <bra> in math-mode = open Dirac bra < | (non-stretchy)
	 ( "b r a" (make-bracket-open "<langle>" "|" ))
;;; <bra var> in math-mode = open Dirac bra < only (non-stretchy). Alternatively typ <bra> + <del>
	 ("b r a var" "<langle>")
;;; <bra var var> in math-mode = open Dirac bra < | (stretchy)
	 ( "b r a var var" (make-bracket-open "langle" "|"  #t))
;;;; <ket> in math-mode = close Dirac ket | > (non-stretchy)
	 ("k e t" (make-bracket-open "|" "<rangle>" ))
;;;; <ket var> in math-mode = close Dirac ket > only (non-stretchy). Alternatetivley type <ket> + <backspc>
	 ("k e t var" "<rangle>")
;;;; <ket  var var> in math-mode = close Dirac ket | > (stretchy)
	 ( "k e t var var" (make-bracket-open "|" "rangle" #t))
;( "|" (make-bracket-open "<lfloor>" "<rfloor>"  #t))
;( "A-|" (make-bracket-close "<rfloor>" "<lfloor>" #t))
;	  ("b r a var" (make-bracket-open "langle" "rangle" #t))
;  ("k e t" (make-bracket-close "rangle" "langle" #t))




;;; Decorations
;;;; Allow you to first type somestuff and add accents and some fancy stuff later
;;;; i.e. these are typed when the cursor is positioned BEHIND the character!
;;;; 
;;; Control = Decorations mostly used with Expressions (braces, text, etc)
;;;; <Control-\>= NOT sure whether selections are more often used than under/overbraced
;;;; <> in math-mode = brace under expression
	 ("C-\]" (make-wide-under "<wide-underbrace>")
	  ) 
;;;; <> in math-mode = brace over expression
	 ("C-\[" (make-wide "<wide-overbrace>") )
;;;; <> in math-mode = right arow over expression (variation of  >  = Shift-.)
	 ("C-\." (make-wide "<wide-varrightarrow>") )
;;;; <> in math-mode = left arrow over expression (variation of < = Shift-,)
	 ("C-\,"  (make-wide "<wide-varleftarrow>") )
;;;; <Ctrl--> in math-mode = box under expression
	 ("C-\-" (begin (kbd-select kbd-left)
			(make-below)
			)
	  )
;;;; <Ctrl-6> in math-mode = box over expression
	 ("C-6" (begin (kbd-select kbd-left)
		       (make-above)
		       )
	  )

;;; Alt = Decorations mostly used with Characters (hats, dots, etc) but work also with expressions
;;;; <Alt-6> in math-mode = hat (variation of  <Shift-6> = ^)
	 ("A-6" (begin (kbd-select kbd-left)
		       (make-wide "^")
		       )
	  )
;;;; <Alt-.> in math-mode = dot above
	 ("A-." (begin (kbd-select kbd-left)
		       (make-wide "<dot>")
		       )
	  )
;;;; <Alt-\> in math-mode = over bar
	 ("A-\-" (begin (kbd-select kbd-left)
			(make-wide "<bar>")
			)
	  )
;;;; <Alt-'> in math-mode = check
	 ("A-'" (begin (kbd-select kbd-left)
		       (make-wide "<check>")
		       )
	  )
;;;; <Alt-\> in math-mode = ???
	 ("A-\"" (begin (kbd-select kbd-left)
			(make-wide "\"")
			)
	  )
;;;; <Alt-`> in math-mode = tilde (variation of ~ = <Shift-`>)
	 ("A-`" (begin (kbd-select kbd-left)
		       (make-wide "~")
		       )
	  )

;;;; <=Eq.> in math-mode = equal to, following from equation whose reference is inserted
;;BUG =eq don't work insert "=" doesn't work together with make-above?
;	 ("= e q"  	(begin (make-above)
;			       (insert "=")
;			       (go-up) ;(kbd-up)
;			       (make-with "mode" "text")
;			       (insert "(")
;			       (make 'reference)
;			       (insert "eq:")
;			       (kbd-right)
;			       )
;	 ("= E q ."  	(begin (insert "=")
;			       (kbd-select kbd-left)
;			       (make-above)
;			       (make-with "mode" "text")
;			       (insert "(")
;			       (make 'reference)
;			       (insert "eq:")
;			       )
;; IDEA make = with Eq. () above it a variation of =
;	 ("= var var var var var" "blabla")

;;; Algebra
;;;; <sum> in math-mode = summation + jump to subscript
	 ("s u m" (begin (make-big-operator "sum")
			 (make-script #f #t)
			 )
	  )
;;;; <prod> in math-mode = product + jump to subscript
	 ("p r o d" (begin (make-big-operator "prod")
			   (make-script #f #t)
			   )
	  )
;;;; </> in math-mode = </> = fraction, first type numerator then / and continue typing denominator!
	 ("/"  (begin (kbd-select kbd-left)
		      (make-fraction)
		      )
	  )
;;;; <Ctrl-/> in math-mode = </> = fraction, numerator = first make selection of numerator expression (multi-character!), C-/ makes fraction
	 ("C-/" (make-fraction))
;;;; <Alt-/> in math-mode = plain / for inline equation (used less often than fraction)
	 ("A-/" (insert "/"))

;;; Functions
;;;; <exp> in math-mode = e + jumpt to superscript
	 ("e x p var" (begin (insert "e")
			 (make-script #t #t)
			 )
	  )

;;;; <sqrt> in math-mode = square root
	 ("s q r t" (make-sqrt))

;;; Integral operators
;;;; <int> in math-mode = integral
	 ("i n t" (make-big-operator "int"))
;;;; <Iint> in math-mode = integral with limits above/below
	 ("I n t" (make-big-operator "intlim"))
;;;; <d2> in math-mode = 2d volume element
	 ("d 2" (begin (insert "d")
		       (make-rprime "2")
		       )
	  )
;;;; <d3> in math-mode = 3d volume element
	 ("d 3" (begin (insert "d")
		       (make-rprime "3")
		       )
	  )
;;;; <d4> in math-mode = 4d volume element
	 ("d 4" (begin (insert "d")
		       (make-rprime "4")
		       )
	  )

;;; Differential operators
;;;; <div> in math-mode = nabla dot
	 ("d i v" (insert "<nabla><cdot>"))
;;;; <rot> in math-mode = nabla x
	 ("r o t" (insert "<nabla><times>"))
;;;; <nab> in math-mode = nabla
	 ("n a b" (insert "<nabla>"))
;;;; <grad> in math-mode = nabla
	 ("g r a d" (insert "<nabla>"))
;;;; <dd> in math-mode = d/d + jump to lower d
	 ("d d" (insert '(frac "d" "d")))
	 ("d d var" (insert '(frac "d" "d")))
;;;; <DD> in math-mode = partial d/d + jump to lower
	 ("D D" (begin (insert '(frac "<partial>" "<partial>"))
		       (kbd-left)
		       )
	  )
	 ("D 2 D D" (begin 
;; BUG D2DD don't work
;		      (make-fraction)
		     (insert '(frac "<partial>" "<partial><partial>"))
		     ;(go-left) (insert '(rsup "2"))
		     ;(position-left)
		     ;(go-up)
		     ; (insert "<partial>")
		      ;(insert '(rsup "2"))
		     ; (kbd-select-left)
		     ; (make-fraction)
;		      (kbd-down)
;		      (insert "<partial><partial>")
;		     (insert '(frac  (insert "<partial>") "<partial><partial>"))
;		      (kbd-left)
;		      (insert "<partial>")
;		      (insert '(rsup "2"))

		       )
	  )

;;;  Special Symbols
;;;; <hb> in math-mode =  h-bar
	 ("h b" "<hbar>")
;;;; <inf> in math-mode = infinity
	 ("i n f" "<infty>")
;;;; <hc> in math-mode = hermitian conjugate dagger
	 ("h c" (make-rprime "<dag>") )
;;;; <cc> in math-mode =complex conjugate
	 ("c c" (make-rprime "<ast>") )
;;;; <up> in math-mode = spin up
	 ("u p" "<uparrow>")
;;;; <dn> in math-mode =spin down
	 ("d n" "<downarrow>")
;;;; <perp> in math-mode = perpendicular to
	 ("p e r p" (insert "<perp>"))
;;;; <para> in math-mode = parallel to
	 ("p a r a" (insert "<parallel>"))

;;; Equations/Comparisons
;;;; <ae> in math-mode = approximately equal
	 ("a e" "<approx>")
;;;; <prop> in math-mode = approximately equal
	 ("p r o p" "<propto>")
;;;; <def> in math-mode = defined as
	 ("d e f" "<equiv>")

;;; Linear Algerbra
;;;; <in> in math-mode = inner product
	 ("i n" "<cdot>")
	 ("i n var" "in")
;;;; <out> in math-mode = outer product
	 ("o u t" "<times>")

;;; Sets
;;;; <el> in math-mode = element of set
	 ("e l" "<in>")
	 ("e l var" "el")

;;; Labels & Numbers
;;;;    Insert a label in math-mode for an object/environment with the proper prefix "eq:", "chap:" etc.
;;;;    In text-mode these same commands will insert a REFERENCE these labels!
;;;;    It is good custom to keep track of labels for different types of objects by using a prefix
;;;;    e.g. equations have labels "eq:xxx"
;;;;
;;;; <Eq.> in math-mode = Insert label for equation with the "eq:" prefix already in place
	 ("E q ." (begin (make 'label)
			 (insert "eq:")
			 )
	  )
;;;; <Fig.> in math-mode = Insert label for Figure with the "fig:" prefix already in place
	 ("F i g ." (begin (make 'label)
			   (insert "fig:")
			   )
	  )
;;;; <Tab.> in math-mode = Insert label for Table with the "tab:" prefix already in place
	 ("T a b ." (begin (make 'label)
			   (insert "tab:")
			   )
	  )
;;;; <Chap.> in math-mode = Insert label for Chapter with the "chap:" prefix already in place
	 ("C h a p ." (begin (make 'label)
			     (insert "chap:")
			     )
	  )
;;;; <Sec.> in math-mode = Insert label for Section with the "sec:" prefix already in place
	 ("S e c ." (begin (make 'label)
			   (insert "sec:")
			   )
	  )

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
)
