;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;
;; MODULE      : kbd-theophys-text.scm
;; DESCRIPTION : keybindings effective in text-mode only
;;
;; COPYRIGHT   : (C) 2003  Maarten Wegewijs
;;
;; This software falls under the GNU general public license and comes WITHOUT
;; ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for details.
;; If you don't have this file, write to the Free Software Foundation, Inc.,
;; 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(texmacs-module (keyboard kbd-theophys-text)
  (:use (utils edit auto-close)))
(kbd-map
 (:mode in-text?)
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;;; Formatting Characters
;;;; <Ctrl-b> in text-mode = bold font
	 ("C-b" (make-with "font-series" "bold"))
;;;; <Ctrl-i> in text-mode = italic font
	 ("C-i" (make-with "font-shape" "italic"))

;;; Insert math

;;;; <Alt-Return> in text-mode = Insert equation array
	 ("S-return"
	  (begin (make  'eqnarray*) (temp-proof-fix)))
;;;; <Control-Return> in text-mode = Insert multiline equation Numbered
	 ("C-return"
	  (begin (make 'equation*) (temp-proof-fix)))
;;;; <Shift-Return> in text-mode = Insert single equation Unnumbered
	 ("A-return"
	  (begin (make 'equation) (temp-proof-fix)))

;;; References in text-mode to labels
;;;; Create these labes using the same commands, but issued in math-mode!
;;;;
;;;; <Eq.> in text-mode = Insert reference to equation whose label starts with "eq:" preceded by abbreviation"Eq. ("
	 ("E q ." (begin (insert "Eq. (")
			 (make 'reference)
			 (insert "eq:")
			 )
	  )
;;;; <eq.> in text-mode = Insert reference to equation whose label starts with "eq:"
	 ("e q ." (begin (insert "(")
			 (make 'reference)
			 (insert "eq:")
			 )
	  )
;;;; <Ref.> in text-mode = Insert reference to bibliographic item whose label starts with "bib:" preceded by abbreviation "Ref. ("
	 ("R e f ." (begin  (make  'cite) ;(make-inactive-apply-arg "cite")
			    (insert "bib:")
			    )
	  )
;;;; <ref.> in text-mode = Insert reference to bibliographic item whose label starts with "bib:"
	 ("r e f ." (begin  (make  'cite) ;(make-inactive-apply-arg "cite")
			    (insert "bib:")
			    )
	  )
;;;; <Fig.> in text-mode = Insert reference to figure whose label starts with "fig:" preceded by abbreviation "Fig. ("
	 ("F i g ." (begin (insert "Fig. (")
			   (make 'reference)
			   (insert "fig:")
			   )
	  )
;;;; <fig.> in text-mode = Insert reference to figure whose label starts with "fig:"
	 ("f i g ." (begin (insert "(")
			   (make 'reference)
			   (insert "fig:")
			   )
	  )
;;;; <Tab.> in text-mode = Insert reference to table whose label starts with "tab:" preceded by "Table ("
;;;;    NOTE: no conflict with the replacement <tab> which only occurs in mathmode!
	 ("T a b ." (begin (insert "Table (")
			   (make 'reference)
			   (insert "tab:")
			   )
	  )
;;;; <Tab.> in text-mode = Insert reference to table whose label starts with "tab:"
;;;;    NOTE: no conflict with the replacement <tab> which only occurs in mathmode!
	 ("t a b ." (begin (insert "(")
			   (make 'reference)
			   (insert "tab:")
			   )
	  )
;;;; <Pr.> in text-mode = Insert proof environment
	 ("P r ."  (begin (make  'proof) )
	  )
;;;; <Ex.> in text-mode = Insert example environment
	 ("E x ."  (begin (make 'example) )
	  )

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
)
